@@ -48,24 +48,35 @@ for my $constant ( $xml->getElementsByTagName('PhysicalConstant') ) {
 		}
 	}
 
+	# recognise that there can be more than one alternateName
+	my $alternate = undef;
+	my @alternates = ();
+	if ( $constant->getChildrenByTagName('alternateName') ) {
+		for my $node ( $constant->getChildrenByTagName('alternateName') ) {
+			$alternate = $node->textContent();
+			next unless $alternate =~ /\S/;
 
-	write_method_pod($ac_fh, $long_name, $short_name, $description, $values);
+			push @{$tagname->{alternates}}, $alternate;
+			push @{$tagname->{long}}, $alternate;
+			push @alternates, $alternate;
+
+			write_constant($mks_fh, ($values->{mks} || $values->{value}), $alternate) 
+				if $values->{mks} || $values->{value};
+			write_constant($cgs_fh, ($values->{cgs} || $values->{value}), $alternate) 
+				if $values->{cgs} || $values->{value};
+		}
+	}
+
+	#### write to the module files
+	write_method_pod($ac_fh, $long_name, $short_name, $description, $values, \@alternates);
 	write_constant($mks_fh, ($values->{mks} || $values->{value}), $long_name, $short_name) 
 			if $values->{mks} || $values->{value};
 	write_constant($cgs_fh, ($values->{cgs} || $values->{value}), $long_name, $short_name) 
 			if $values->{cgs} || $values->{value};
 
-
 	push @{$tagname->{long}}, $long_name if $long_name;
 	push @{$tagname->{short}}, '$' . $short_name if $short_name;
 		
-	my $alternate = undef;
-	if ( $constant->getChildrenByTagName('alternateName')
-			&& ($alternate = $constant->getChildrenByTagName('alternateName')->shift()->textContent()) ) {
-		push @{$tagname->{long}}, $alternate;
-		write_constant($mks_fh, ($values->{mks} || $values->{value}), $alternate) if $values->{mks} || $values->{value};
-		write_constant($cgs_fh, ($values->{cgs} || $values->{value}), $alternate) if $values->{cgs} || $values->{value};
-	}
 
 	for my $cat_node ( $constant->getElementsByTagName('category') ) {
 		my $category =	$cat_node->textContent();
@@ -90,17 +101,14 @@ sub write_module_header {
 package $name;
 # ABSTRACT: this library provides physical constants for use in Astronomy
 
-HEADER
-	if ($name eq 'Astro::Constants') {
-		print $fh "'They are not constant but are changing still. - Cymbeline, Act II, Scene 5';\n\n";
-	}
-	else {
-		print $fh <<IMPORT;
 use strict;
 use warnings;
-use base qw/Exporter/;
-
-IMPORT
+HEADER
+	if ($name eq 'Astro::Constants') {
+		print $fh "\n  'They are not constant but are changing still. - Cymbeline, Act II, Scene 5';\n\n";
+	}
+	else {
+		print $fh "use base qw/Exporter/;\n\n";
 	}
 }
 
@@ -139,7 +147,7 @@ FOOT
 }
 
 sub write_method_pod {
-	my ($fh, $long_name, $short_name, $description, $values) = @_;
+	my ($fh, $long_name, $short_name, $description, $values, $alt_ref, ) = @_;
 
 	my $display;
 	$display .= "    $values->{mks}\tMKS\n" if $values->{mks};
@@ -154,7 +162,23 @@ $display
 $description
 
 POD
-	say $fh "This constant can also be accessed through the variable \$$short_name (which may be deprecated)\n" if $short_name;
+	say $fh "This constant is also available using the short name C<\$$short_name>" if $short_name;
+	if ($short_name && @$alt_ref > 1) {
+		say $fh 'as well as these alternate names (imported using the :alternate tag): ', join ', ', @$alt_ref;
+	}
+	elsif ($short_name && @$alt_ref) {
+		say $fh 'as well as the alternate name C<', $alt_ref->[0], 
+				"> (imported using the :alternate tag for backwards compatibility)";
+	}
+	elsif (@$alt_ref > 1) {
+		say $fh "This constant is also available using these alternate names (imported using the :alternate tag): ", 
+				join ', ', @$alt_ref;
+	}
+	elsif (@$alt_ref) {
+		say $fh "This constant is also available using the alternate name C<", $alt_ref->[0], 
+                "> (imported using the :alternate tag for backwards compatibility)";
+	}
+	print $fh "\n";
 }
 
 sub write_pod_synopsis {
@@ -163,11 +187,11 @@ sub write_pod_synopsis {
 	say $fh <<'POD';
 =head1 SYNOPSIS
 
-	use strict;		# important!
+    use strict;		# important!
     use Astro::Constants::MKS qw/:long/;
 
-	# to calculate the gravitational force of the Sun on the Earth in Newtons, use GMm/r^2
-	my $force_sun_earth = GRAVITATIONAL * MASS_SOLAR * MASS_EARTH / ASTRONOMICAL_UNIT**2;
+    # to calculate the gravitational force of the Sun on the Earth in Newtons, use GMm/r^2
+    my $force_sun_earth = GRAVITATIONAL * MASS_SOLAR * MASS_EARTH / ASTRONOMICAL_UNIT**2;
 
 =head1 DESCRIPTION
 
@@ -220,15 +244,16 @@ Nothing is exported by default, so the module doesn't clobber any of your variab
 Select from the following tags:
 
 =for :list
-* long		(use this one to get the most constants)
-* short
-* fundamental
-* conversion
-* mathematics
-* cosmology
-* planetary
-* electromagnetic
-* nuclear
+* :long		(use this one to get the most constants)
+* :short
+* :fundamental
+* :conversion
+* :mathematics
+* :cosmology
+* :planetary
+* :electromagnetic
+* :nuclear
+* :alternates
 
 POD
 }
@@ -254,25 +279,30 @@ the documentation.  Use C<perldoc Astro::Constants> for that information.
 
 =for :list
 * L<Astro::Cosmology>
-* L<PDL|Perl Data Language>
-* L<http://physics.nist.gov/|NIST>
-* L<http://asa.usno.navy.mil|Astronomical Almanac>
-* L<http://neilb.org/reviews/constants.html|Neil Bower's review on providing read-only values>
+* L<Perl Data Language|PDL>
+* L<NIST|http://physics.nist.gov>
+* L<Astronomical Almanac|http://asa.usno.navy.mil>
+* L<Neil Bower's review on providing read-only values|http://neilb.org/reviews/constants.html>
 * L<Test::Number::Delta>
 * L<Test::Deep::NumberTolerant> for testing values within objects
 
 Reference Documents:
+
 =for :list
-* L<http://aa.usno.navy.mil/publications/reports/Luzumetal2011.pdf|IAU 2009 system of astronomical constants>
-* L<http://asa.usno.navy.mil/static/files/2016/Astronomical_Constants_2016.pdf|Astronomical Constants 2016.pdf>
-* L<https://www.iau.org/publications/proceedings_rules/units/|IAU recommendations concerning units>
-* L<http://syrte.obspm.fr/IAU_resolutions/Res_IAU2012_B2.pdf|Re-definition of the Astronomical Unit>
+* L<IAU 2009 system of astronomical constants|http://aa.usno.navy.mil/publications/reports/Luzumetal2011.pdf>
+* L<Astronomical Constants 2016.pdf|http://asa.usno.navy.mil/static/files/2016/Astronomical_Constants_2016.pdf>
+* L<IAU recommendations concerning units|https://www.iau.org/publications/proceedings_rules/units>
+* L<Re-definition of the Astronomical Unit|http://syrte.obspm.fr/IAU_resolutions/Res_IAU2012_B2.pdf>
+
+=head1 REPOSITORY
+
+* L<https://github.com/duffee/Astro-Constants>
 
 =head1 ISSUES
 
-File issues/suggestions at the Github repository L<https://github.com/duffee/Astro-Constants/>.
-The venerable L<https://rt.cpan.org/Dist/Display.html?Status=Active&Queue=Astro-Constants|RT>
-is the canonical bug tracker that is clocked by L<https://metacpan.org/pod/Astro::Constants|meta::cpan>.
+File issues/suggestions at the Github repository L<https://github.com/duffee/Astro-Constants>.
+The venerable L<RT|https://rt.cpan.org/Dist/Display.html?Status=Active&Queue=Astro-Constants>
+is the canonical bug tracker that is clocked by L<meta::cpan|https://metacpan.org/pod/Astro::Constants>.
 
 Using C<strict> is a must with this code.  Any constants you forgot to import will
 evaluate to 0 and silently introduce errors in your code.  Caveat Programmer.
@@ -283,7 +313,7 @@ disposal, including
 What new features would you like to see?
 If you've had an experience with using the module, let other people know what you
 think, good or bad, by rating it at
-L<http://cpanratings.perl.org/rate/?distribution=Astro-Constants|cpanratings>.
+L<cpanratings|http://cpanratings.perl.org/rate/?distribution=Astro-Constants>.
 
 =head2 Extending the data set
 
@@ -307,7 +337,7 @@ important information coming at the beginning of the name.
 =head1 ASTROCONST  X<ASTROCONST>
 
 (Gleaned from the Astroconst home page -
-L<http://web.astroconst.org|http://web.astroconst.org> )
+L<astroconst.org|http://web.astroconst.org> )
 
 Astroconst is a set of header files in various languages (currently C,
 Fortran, Perl, Java, IDL and Gnuplot) that provide a variety of useful
